dag.init is used for setting up DAGs. See the code of the functions demo.dag0 to demo.dag6 for example code.
To adjust and/or evalute DAGs for biasing paths, use dag.adjust, dag.draw for drawing a DAG.
dag.search uses brute.search to evaluate all possible adjustment sets, allowing the identification of minimal sufficient adjustment sets using msas.
At present, summary_dagRdag can summarize a DAG object. This should later become an S3 method.
Several helper functions currently are not hidden and should later be made internal.
Please see the NEWS file for version changes and known open issues.dag1<-demo.dag1();
dag.draw(dag1);
dag1a<-dag.adjust(dag1, 3);
dag.draw(dag1a);
dag1s<-dag.search(dag1);
summary_dagRdag(dag1);
summary_dagRdag(dag1a);
summary_dagRdag(dag1s);Run the code above in your browser using DataLab